#[non_exhaustive]pub enum MoneyAmountParseError {
InvalidFormat,
OutOfRange,
Negative,
WrongPrecision {
money: u32,
token: u32,
},
}Expand description
Errors that can occur when parsing a monetary amount.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidFormat
The input string could not be parsed as a number.
OutOfRange
The value is outside the allowed range.
Negative
Negative values are not allowed.
WrongPrecision
The input has more decimal places than the token supports.