pub struct MaxAmountPolicy(pub u128);Expand description
Keeps only candidates whose amount is at most the configured bound.
Tuple Fields
0: u128Trait Implementations
Sourceimpl Clone for MaxAmountPolicy
impl Clone for MaxAmountPolicy
Sourcefn clone(&self) -> MaxAmountPolicy
fn clone(&self) -> MaxAmountPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MaxAmountPolicy
Sourceimpl Debug for MaxAmountPolicy
impl Debug for MaxAmountPolicy
Sourceimpl PaymentPolicy for MaxAmountPolicy
impl PaymentPolicy for MaxAmountPolicy
Sourcefn apply<'a>(
&self,
candidates: Vec<&'a PaymentCandidate>,
) -> Vec<&'a PaymentCandidate>
fn apply<'a>( &self, candidates: Vec<&'a PaymentCandidate>, ) -> Vec<&'a PaymentCandidate>
Returns the subset of candidates that pass this policy.