pub struct SchemeSlug {
pub chain_id: ChainId,
pub name: CompactString,
}Expand description
Unique identifier for a scheme handler instance.
Fields
chain_id: ChainIdChain this handler operates on.
name: CompactStringScheme name (e.g. "exact", "upto").
Implementations
Sourceimpl SchemeSlug
impl SchemeSlug
Sourcepub const fn new(chain_id: ChainId, name: CompactString) -> Self
pub const fn new(chain_id: ChainId, name: CompactString) -> Self
Constructs a new slug.
Sourcepub fn as_wildcard(&self) -> Self
pub fn as_wildcard(&self) -> Self
Returns a wildcard version with the reference replaced by *.
Sourcepub fn is_wildcard(&self) -> bool
pub fn is_wildcard(&self) -> bool
Returns true when the reference is the wildcard *.